<?php
/*
Plugin Name: AMM - Amazon Media Management Extension
Plugin URI: http://www.sozu.co.uk/software/amm/
Description: The Amazon Media Manager for Wordpress 1.5
Version: 1.5
Author: Denyerec and Marcel Dunn
Author URI: http://www.sozu.co.uk
*/

// AMM_LEVEL defines the MINIMUM userlevel required to manage Amazon Media Manager
define('AMM_LEVEL', 8);
define('AMM_URL', $_SERVER['PHP_SELF'] . '?page=amm.php');
define('AMM_DOM', 'amm');
load_plugin_textdomain(AMM_DOM);

require_once(ABSPATH.'wp-content/plugins/amm/amm_constants.php');
require_once(ABSPATH.'wp-content/plugins/amm/amm_output.php');

// Security modification.
// Create array of functions available in amm_extras.php for validation
// user templates are then checked against this array in amm_output.php
	$sz_deffunc = get_defined_functions();
	require_once(ABSPATH.'wp-content/plugins/amm/amm_extras.php');
	$sz_deffunc2 = get_defined_functions();
	$sz_deffunc = array_diff($sz_deffunc2['user'], $sz_deffunc['user']);
	unset($sz_deffunc2);
// End security modification

function amm_install () {
	global $table_prefix, $user_level, $wpdb;

	$table_name = $table_prefix . AMM_TABLE;
	get_currentuserinfo();
	if ($user_level < 8) { return false; };
	$tables = array();
	$tables = $wpdb->get_results('SHOW TABLES FROM '.DB_NAME.';', ARRAY_N);

	$first_install = false;

	if (!in_array($table_name, $tables)) {
		$first_install = true;
	}

	$sql = "CREATE TABLE ".$table_name." (
			  amm_itemId bigint(20) unsigned NOT NULL auto_increment,
			  amm_author varchar(128) NOT NULL default '',
			  amm_director varchar(128) NOT NULL default '',
			  amm_title varchar(200) NOT NULL default '',
			  amm_asin varchar(32) NOT NULL default '',
			  amm_productGroup varchar(128) NOT NULL default '',
			  amm_publisher varchar(128) NOT NULL default '',
			  amm_artist varchar(128) NOT NULL default '',
			  amm_label varchar(128) NOT NULL default '',
			  amm_manufacturer varchar(128) NOT NULL default '',
			  amm_model varchar(128) NOT NULL default '',
			  amm_brand varchar(128) NOT NULL default '',
			  amm_userComments text NOT NULL,
			  amm_rating smallint(10) NOT NULL default '0',
			  amm_country varchar(8) NOT NULL default '',
			  amm_dateadded datetime NOT NULL default '0000-00-00 00:00:00',
			  amm_smallImageURL varchar(200) NOT NULL default '',
			  PRIMARY KEY  (amm_itemId)
			) ";


	require_once(ABSPATH . 'wp-admin/upgrade-functions.php');
	dbDelta($sql);

	/**
	 * The following WP options are used to control certain aspects of
	 * the system. An admin interface for these variables may be provided at some time
	 * in the future.
	 */
	$tmp = get_option('amm_country');
	if ( !$tmp ) update_option('amm_country', AMM_COUNTRY);
	$tmp = get_option('amm_associd');
	if ( !$tmp ) update_option('amm_associd', AMM_AFFILIATE);
	$tmp = get_option('amm_devid');
	if ( !$tmp ) update_option('amm_devid', AMM_DEVKEY);
	$tmp = get_option('amm_perpage');
	if ( !$tmp ) update_option('amm_perpage', 30);
	$tmp = get_option('amm_amazondesc');
	if ( !$tmp ) update_option('amm_amazondesc', false);

	if ($first_install){
		// Ping Sozu.co.uk to indicate successful installation
		$thisurl = 'http://' . $_SERVER['SERVER_NAME'] . str_replace ('\\','/',substr (dirname (__FILE__),strlen ($_SERVER['DOCUMENT_ROOT']))) . '/';
		$url = 'www.sozu.co.uk';
		$uri = '/tracker/tracker.php?url=www.'.$thisurl.'&id=7NVLL0OPSA3A22CB';

		if(preg_match('!^http://!',$url))
		$url=substr($url,7,strlen($url));

		$fp=@fsockopen($url,80,$errno,$errstr,4);
		if(!$fp)
		{
			return false;
		}
		else
		{
			$buffer='';
			$headers='';
			fputs($fp,"GET $uri HTTP/1.0\r\n");
			fputs($fp,"Host: $url\r\n");
			fputs($fp,"User-Agent: AMMInstalled\r\n");
			fputs($fp,"Connection: close\r\n");
			fputs($fp,"\r\n");
			fclose($fp);
			return true;
		}
	}
}

function amm_isEmpty($field) {
	if (strlen($field) == 0) {
		return '<span class="amm_err">* '.__('This field must not be empty', AMM_DOM).' *</span><br />';
	}
	else {
		return '';
	}
}

function amm_addmenuitems() {
	if (function_exists('add_management_page')) {
		add_management_page('AMM Manager', 'AMM', AMM_LEVEL, __FILE__, 'amm_Manager');
	}
	if (function_exists('add_submenu_page')) {
		add_submenu_page('options-general.php','Amazon Media Manager Options', 'AMM', AMM_LEVEL, __FILE__, 'amm_Options');
	}
}


function amm_css() {
	echo "
	<style type='text/css'>
	    .amm_form fieldset { padding: 10px; }
	    .amm_form label { float: left; width: 140px; text-align: right; padding-right: 10px; padding-top: 2px;}
	    .amm_form .amm_inline {float: none; text-align: left; }
	    .amm_form textarea{ margin-bottom: 5px; }
	    .amm_form br.amm{ clear: left; margin: 3px; display: block;}
	    .amm_form span.amm_err { padding-left: 160px; }
	    .amm_form .submit {display: block; clear: both;}
	    .amm_form img { clear: both; border: 1px solid #ccc; padding: 30px; background-color: #fafafa; }
	    .amm_form .amm_detail {width: 40%; margin-left: 30px;}

	    .amm_pageNumber a{ margin: 0 3px; clear: none; }
	    .amm_pageNumber { text-align: right; margin: 5px 0px; }
	    .amm_pageNumber .highlight { border: 1px #ddd solid; padding: 3px; }
	</style>
	";
}

function amm_getMediaInline($content = ''){
	global $post;
	// wrapper function to detect <!--getmediaInline--> calls on posts with suitable META

	$metacheck = get_post_meta($post->ID,'amm',true);
	if ('enabled' == $metacheck){
		// if (content meta has amm:enabled in it) {
		$content = preg_replace("/<!--amm_getMedia\\050([\\w'\\-,_\\|\\s]*)\\051-->/e","amm_getMediaInlineWrapper('\\1')",$content);
		// }
	}
	return $content;
}

function amm_getMediaIDInline($content = ''){
	global $post;
	// wrapper function to detect <!--getmediaInline--> calls on posts with suitable META

	$metacheck = get_post_meta($post->ID,'amm',true);
	if ('enabled' == $metacheck){
		// if (content meta has amm:enabled in it) {
		$content = preg_replace("/<!--amm_getMediaID\\050([\\w'\\-,_\\|\\s]*)\\051-->/e","amm_getMediaIDInlineWrapper('\\1')",$content);
		// }
	}
	return $content;
}

//function amm_getMediaInlineWrapper($template='amm_default_output',$items=1, $groups=AMM_ALL, $sort=AMM_DATE_DESC, $rating=AMM_RATING_ALL){
function amm_getMediaInlineWrapper($string){

	$string = stripslashes($string);
	// open buffer
	ob_start();
	// call getmedia
	eval("amm_getMedia($string);");
	// pass buffer to variable
	$output = ob_get_contents();
	// close and clear buffer
	ob_end_clean();
	return $output;
}

function amm_getMediaIDInlineWrapper($string){
	$string = stripslashes($string);
	ob_start();
	eval("amm_getMediaID($string);");
	$output = ob_get_contents();
	ob_end_clean();
	return $output;
}


/**
* Function to render a productGroup combobox, with the passed-in parameter defining
* which option is selected by default.
**/
function amm_productCombo ($productGroup) {
	$lpg = strtolower($productGroup); //lowercase for safety
	$prodgroups = array('Apparel', 'Book', 'Automotive Parts and Accessories', 'Baby', 'Baby Product',
	'Beauty', 'CE',     'Gourmet', 'Health and Beauty', 'Home Improvement', 'Jewelery',
	'Kitchen', 'Lawn  Patio',     'Musical Instruments', 'Office Product', 'Personal Computer',
	'Photography', 'Single Detail Page Misc', 'Software', 'Sports', 'Toys', 'Wireless',
	'Wireless Phone Accessory', 'Watch', 'Video Games', 'Magazine', 'Video', 'DVD',
	'Downloadable Music',     'Music');

	// Too lazy to sort above list by hand... :(
	sort($prodgroups);
	foreach ($prodgroups as $value) {
		$selected = $lpg == strtolower($value) ? ' selected="selected"' : '';
		echo '<option value="' . $value . '"' . $selected . '>' . $value . '</option>';
	}
}

function amm_stripEscape($string) {
	echo $string;
	echo substr($string,1,strlen($string)-2);
	return substr($string,1,strlen($string)-2);
}


/**
	 * Returns the URL for an amazon image, autogenerated from the current item ASIN
	 * Parameter can be desired output size as Integer, or 'small', 'medium' or 'large'
	 * @param variant $size
	 * @return string
	 */

function makeImage($asin,$country='us'){

	switch($country){
		case 'jp':
		$image = 'http://images-jp.amazon.com/images/P/' . $asin . '.09.THUMBZZZ.jpg';
		break;

		case 'uk':
		case 'fr':
		case 'de':
		$image = 'http://images-eu.amazon.com/images/P/' . $asin . '.02.THUMBZZZ.jpg';
		break;

		case 'ca':
		case 'us':
		default:
		$image = 'http://images.amazon.com/images/P/' . $asin . '.01.THUMBZZZ.jpg';
		break;
	}
	$imageinfo = array(0,0);
	$imageinfo = @getimagesize($image);
	if ($imageinfo[0] <= 1) $image='http://g-images.amazon.com/images/G/01/x-site/icons/no-img-sm.gif';
	return $image;
}

/**
 * Returns the URL for the detail page at the respective Amazon country website
 * @param string Country
 * @param string ASIN
 */

function amm_detailURL($country, $asin){
		//http://www.amazon.com/exec/obidos/ASIN/1560976144/denyersphotog-21/
		switch($country){
			case 'uk':
			$ext = '.co.uk';
			break;
			case 'ca':
			$ext = '.ca';
			break;
			case 'fr':
			$ext = '.fr';
			break;
			case 'de':
			$ext = '.de';
			break;
			case 'jp':
			$ext = '.co.jp';
			break;
			case 'us':
			default:
			$ext = '.com';
			break;
		}
		return 'http://www.amazon' . $ext . '/exec/obidos/ASIN/' . $asin;
	}
	
//=============================================================================
function amm_Manager() {
	include_once(ABSPATH.'wp-content/plugins/amm/amm_parser.php');
	global $wpdb, $table_prefix;							//The Wordpress database resource
	$amm_view				= 'main';		//What view to show
	$amm_data				= 'validate';	//What data is coming
	$amm_setup				= 'main';		//What view should be setup
	$amm_errors				= 0;
	$amm_errMsg				= '';
	$amm_operation 			= array('Operation'=>'ItemSearch','SearchIndex'=>'','Keywords'=>'','ResponseGroup'=>'Images,ItemAttributes');
	$amm_searchResults 		= array();
	$amm_sql				= '';
	$amm_selByPrdGrpControl = array();
	/**
* A little chunk of logic to figure out
* where you were and what the action variable should be
* examine if we've got POST variables or GET variables
* decide what to do with these based on where we are
* coming from.
**/

	//Make sure both the GET and POST variables are properly escaped
	$amm_post = array('amm_itemId'=>'', 'amm_author'=>'','amm_director'=>'','amm_title'=>'','amm_asin'=>'','amm_productGroup'=>'','amm_publisher'=>'','amm_artist'=>'','amm_label'=>'','amm_manufacturer'=>'','amm_model'=>'','amm_brand'=>'','amm_userComments'=>'','amm_rating'=>'','amm_country'=>'','amm_name'=>'','amm_dateadded'=>'');
	if (array_key_exists('amm_name', $_POST)&&(!empty($_POST['amm_name']))) {
		$amm_post = $_POST;
		//We decide what to set our $amm_data variable to based on
		//the $amm_post['name'] or $amm_get['name'] array member.
		switch ($amm_post['amm_name']) {
			case 'frm_searchQuery':
			$amm_data = 'frm_searchQuery';
			break;
			case 'frm_selectedItem':
			$amm_data = 'frm_selectedItem';
			break;
			case 'frm_editItem':
			$amm_data = 'frm_editItem';
			break;
			default:
			$amm_data = '';
			break;
		}
	}
	elseif (array_key_exists('itemId', $_GET)&&(!empty($_GET['itemId']) && is_numeric($_GET['itemId']))) {
		if ((isset($_GET['action']) && ('del' == $_GET['action']))){
			$amm_data = 'lnk_deleteItem';
		}else{
			$amm_data = 'lnk_selectedItem';
		}
	}
	elseif ((array_key_exists('amm_orderButton', $_GET)) || array_key_exists('amm_page', $_GET)) {
		$amm_get = $_GET;
		$amm_data = '';
	}
	else {
		$amm_data = '';
	}

	//=============================================================================
	//Data Controller
	/**
	* The Data Controller handles:
	* [1] validation
	* [2] database interactions
	* [3] set feedback
	* [4] deciding what view to display next
	* The default state is to do no processing
	* and simply display the data table
	**/
	switch ($amm_data) {
		case 'frm_searchQuery':
		//We get the country, searchIndex, and the keyword coming in.
		//Need to make sure that the keyword isn't empty.
		$amm_errMsg .= amm_isEmpty($amm_post['amm_keywords']);
		if ('' != $amm_errMsg ) {
			$amm_errors++;
		}
		//If there are no errors
		if (0 == $amm_errors) {
			//Then do the search.
			if ($amm_post['amm_searchIndex']=='- All -'){$amm_post['amm_searchIndex'] = 'Blended';}
			$amm_operation = array('Operation'=>'ItemSearch','SearchIndex'=>$amm_post['amm_searchIndex'],'Keywords'=>$amm_post['amm_keywords'],'ResponseGroup'=>'Images,ItemAttributes,EditorialReview');
			$amm = @new amazonMediaManager($amm_operation,$amm_post['amm_country']);
			if (false !== get_class($amm)) {
				$amm_searchResults = $amm->doItemSearch();
				if (false === $amm_searchResults) {
					$amm_setup = 'main';
					$amm_view = 'main';
					$amm_feedback = __('Both cURL and fopen failed to connect to Amazon. Please make sure either cURL is installed on your server or that fopen to remote files is enabled. Contact your server administrator for assistance.',AMM_DOM);
					break;
				}
				//Check that the result from Amazon isn't an error message
				if (('False' == $amm_searchResults['ItemSearchResponse']['Items']['Request']['IsValid'])||(('True' == $amm_searchResults['ItemSearchResponse']['Items']['Request']['IsValid'])&&(array_key_exists('Errors',$amm_searchResults['ItemSearchResponse']['Items']['Request'])))) {
					$amm_setup = 'main'; //If an error is received from amazon we go back to the main
					$amm_view = 'main';
					$amm_feedback = $amm_searchResults['ItemSearchResponse']['Items']['Request']['Errors']['Error']['Message'];
				}
				else {
					$amm_setup = 'results';
					$amm_view = 'results';
					$amm_feedback = __('Search was successful',AMM_DOM);
				}
			}
		}
		else {
			$amm_setup = 'main' ;
			$amm_view = 'main';
			$amm_feedback = __('There was an error or no keyword was entered for the search',AMM_DOM);
		}
		break;

		case 'frm_selectedItem':
		//The data to be dealt with here is the data from Amazon
		//The user has selected an item and it simply needs to be
		//passed throught to the View

		$amm_setup = 'new';
		$amm_view = 'item';
		$amm_feedback = __('Item selection successful',AMM_DOM);
		break;

		case 'lnk_deleteItem':
		check_admin_referer();
		$amm_itemId = is_numeric($_GET['itemId']) ? $_GET['itemId'] : -1;
		// try and run query, on fail feedback error.
		$amm_sql = 'DELETE FROM '.$table_prefix.AMM_TABLE.' WHERE amm_itemId='.$amm_itemId.';';
		if ($wpdb->query($amm_sql)){
			$amm_feedback = __('The selected item has been deleted',AMM_DOM);
		}else{
			$amm_feedback = __('An error occurred deleting the selected item',AMM_DOM);
		}
		$amm_setup = 'main';
		$amm_view = 'main';
		break;

		case 'lnk_selectedItem':
		//Select * from wp_amm where amm_id = $_GET['itemId'] return this as an associative array.
		$amm_sql = 'SELECT * FROM '.$table_prefix.AMM_TABLE.' WHERE amm_itemId= '.$_GET['itemId'];
		$amm_post = $wpdb->get_row($amm_sql, ARRAY_A);
		$amm_setup = 'update';
		$amm_view = 'item';
		$amm_feedback = __('Item selection successful',AMM_DOM);
		break;

		case 'frm_editItem':
		//Just need to escape the form fields
		//and insert into the database

		if (isset($_POST['cancel'])){
			$amm_setup = 'main';
			$amm_view = 'main';
			$amm_feedback = '<p>'.__('The item was <strong>not</strong> saved', AMM_DOM).'</p>';
		}else{

			$tmp = array( 'amm_author'=>'','amm_director'=>'','amm_title'=>'','amm_asin'=>'','amm_productGroup'=>'','amm_publisher'=>'','amm_artist'=>'','amm_label'=>'','amm_manufacturer'=>'','amm_model'=>'','amm_brand'=>'','amm_userComments'=>'','amm_rating'=>'','amm_country'=>'','amm_dateadded'=>'','amm_smallImageURL'=>'');


			$tmp['amm_author'] 			= (true === array_key_exists('amm_author', $amm_post)) ?		$amm_post['amm_author']	: '';
			$tmp['amm_director'] 		= (true === array_key_exists('amm_director', $amm_post)) ?		$amm_post['amm_director']: '';
			$tmp['amm_title'] 			= (true === array_key_exists('amm_title', $amm_post)) ?			$amm_post['amm_title']		: '';
			$tmp['amm_asin'] 			= (true === array_key_exists('amm_asin', $amm_post)) ?			$amm_post['amm_asin']		: '';
			$tmp['amm_productGroup'] 	= (true === array_key_exists('amm_productGroup', $amm_post)) ?	$amm_post['amm_productGroup']: '';
			$tmp['amm_publisher'] 		= (true === array_key_exists('amm_publisher', $amm_post)) ?		$amm_post['amm_publisher']	: '';
			$tmp['amm_artist'] 			= (true === array_key_exists('amm_artist', $amm_post)) ?		$amm_post['amm_artist']	: '';
			$tmp['amm_label'] 			= (true === array_key_exists('amm_label', $amm_post)) ?			$amm_post['amm_label']		: '';
			$tmp['amm_manufacturer'] 	= (true === array_key_exists('amm_manufacturer', $amm_post)) ?	$amm_post['amm_manufacturer']: '';
			$tmp['amm_model'] 			= (true === array_key_exists('amm_model', $amm_post)) ?			$amm_post['amm_model']	: '';
			$tmp['amm_brand'] 			= (true === array_key_exists('amm_brand', $amm_post)) ?			$amm_post['amm_brand']	: '';
			$tmp['amm_userComments'] 	= (true === array_key_exists('amm_userComments', $amm_post)) ?	$amm_post['amm_userComments']: '';
			$tmp['amm_rating'] 			= (true === array_key_exists('amm_rating', $amm_post)) ?		$amm_post['amm_rating']	: '';
			$tmp['amm_country'] 		= (true === array_key_exists('amm_country', $amm_post)) ?		$amm_post['amm_country']	: '';
			$tmp['amm_dateadded'] 		= (true === array_key_exists('amm_dateadded', $amm_post)) ?		$amm_post['amm_dateadded']: '';
			$tmp['amm_smallImageURL']	= (true === array_key_exists('amm_smallImageURL', $amm_post)) ?	$amm_post['amm_smallImageURL']: '';
			if (isset($amm_post['amm_updateTime'])) {
				//generate a new timestamp and assign it to $tmp['amm_dateadded']
				$tmp['amm_dateadded'] = date('Y-m-d H:i:s');
			}


			if ( empty($amm_post['amm_itemId']) ) {
				unset($tmp['itemId']);

				$tmp['amm_dateadded'] = date('Y-m-d H:i:s');
				$amm_sql = 'INSERT INTO ' . $table_prefix . AMM_TABLE . ' (
				amm_author,
				amm_director,
				amm_title,
				amm_asin,
				amm_productGroup,
				amm_publisher,
				amm_artist,
				amm_label,
				amm_manufacturer,
				amm_model,
				amm_brand,
				amm_userComments,
				amm_rating,
				amm_country,
				amm_dateadded,
				amm_smallImageURL)
				VALUES (\'';
				$amm_sql .= implode('\', \'',$tmp);
				$amm_sql .= '\');';
			}
			else {
				$tmp['amm_itemId'] 	= (true === array_key_exists('amm_itemId', $amm_post)) ?	$amm_post['amm_itemId']	: '';

				$amm_sql = 'UPDATE ' . $table_prefix . AMM_TABLE . ' SET
				amm_author=\''.$wpdb->escape($tmp['amm_author']).'\',
				amm_director=\''.$wpdb->escape($tmp['amm_director']).'\',
				amm_title=\''.$wpdb->escape($tmp['amm_title']).'\',
				amm_asin=\''.$wpdb->escape($tmp['amm_asin']).'\',
				amm_productGroup=\''.$wpdb->escape($tmp['amm_productGroup']).'\',
				amm_publisher=\''.$wpdb->escape($tmp['amm_publisher']).'\',
				amm_artist=\''.$wpdb->escape($tmp['amm_artist']).'\',
				amm_label=\''.$wpdb->escape($tmp['amm_label']).'\',
				amm_manufacturer=\''.$wpdb->escape($tmp['amm_manufacturer']).'\',
				amm_model=\''.$wpdb->escape($tmp['amm_model']).'\',
				amm_brand=\''.$wpdb->escape($tmp['amm_brand']).'\',
				amm_userComments=\''.$wpdb->escape($tmp['amm_userComments']).'\',
				amm_rating=\''.$wpdb->escape($tmp['amm_rating']).'\',
				amm_country=\''.$wpdb->escape($tmp['amm_country']).'\',
				amm_dateadded=\''.$wpdb->escape($tmp['amm_dateadded']).'\',
				amm_smallImageURL=\''.$wpdb->escape($tmp['amm_smallImageURL']).'\'
				WHERE amm_itemId= \''.$wpdb->escape($tmp['amm_itemId']).'\';';
			}

			if (FALSE !== $wpdb->query($amm_sql)) {
				$amm_setup = 'main';
				$amm_view = 'main';
				$amm_feedback = '<p>'.__('The item has been saved', AMM_DOM).'</p>';
			}
			else {
				$amm_setup = 'invalid' ;
				$amm_view = 'item';
				$amm_feedback = '<p>'.__('A database error ocurred. The item has not been saved.', AMM_DOM).'</p>';

			}
			unset($tmp);
		}
		break;
		default:
		$amm_feedback = '';
		$amm_setup = 'main';
		$amm_view = 'main';
		break;
	}
	//=============================================================================
	//Prepare Controller
	/**
		* The State machine will prepare the
		* selected view by populating a bunch
		* of variables.
		* The possible states are:
		* [1] Main Table
		* [2] Search Results
		* [3] Edit Form for new items
		* [4] Edit Form for an existing item
		* [5] Edit Form for validation failure
		**/
	switch ($amm_setup) {
		//Search Results Table
		case 'results':
		$amm_item = array('DetailPageURL'=>'', 'Author'=>'', 'Director'=>'', 'Title'=>'', 'ProductGroup'=>'', 'Publisher'=>'', 'Artist'=>'', 'Label'=>'', 'Manufacturer'=>'', 'Model'=>'', 'Brand'=>'', 'ASIN'=>'', 'MediumImageURL'=>'','SmallImageURL'=>'','AmazonDescription'=>'');
		$amm_items = array();
		$amm_itemData = array();
		$amm_items = $amm_searchResults['ItemSearchResponse']['Items']['Item'];

		for ($ctr=0;$ctr<sizeof($amm_items);$ctr++) {
			/**
				* Detail Page URL
				* Author
				* Director if this isn't there stuff Studio into this variable.
				* Title
				* Product Group
				* Publisher
				* Artist
				* Label
				* Manufacturer
				* Model
				* Brand
				* ASIN
				* Medium Image URL
				**/
			$amm_itemData[$ctr] = $amm_item;
			$amm_itemData[$ctr]['DetailPageURL'] 	= array_key_exists('DetailPageURL', $amm_items[$ctr]) ? $amm_items[$ctr]['DetailPageURL'] : '';
			$amm_itemData[$ctr]['Author'] 				= array_key_exists('Author', $amm_items[$ctr]['ItemAttributes']) ? $amm_items[$ctr]['ItemAttributes']['Author'] : '';

			// If director is blank, map studio into the director field
			if (array_key_exists('Director', $amm_items[$ctr]['ItemAttributes'])) {
				$amm_itemData[$ctr]['Director'] = $amm_items[$ctr]['ItemAttributes']['Director'];
			}
			else {
				$amm_itemData[$ctr]['Director'] = array_key_exists('Studio', $amm_items[$ctr]['ItemAttributes']) ? $amm_items[$ctr]['ItemAttributes']['Studio'] : '';
			}
			$amm_itemData[$ctr]['Title'] 				= array_key_exists('Title', $amm_items[$ctr]['ItemAttributes'])	?	$amm_items[$ctr]['ItemAttributes']['Title'] : '';
			$amm_itemData[$ctr]['ProductGroup'] = array_key_exists('ProductGroup', $amm_items[$ctr]['ItemAttributes'])	?	$amm_items[$ctr]['ItemAttributes']['ProductGroup'] : '';
			$amm_itemData[$ctr]['Publisher'] 		= array_key_exists('Publisher', $amm_items[$ctr]['ItemAttributes'])	?	$amm_items[$ctr]['ItemAttributes']['Publisher'] : '';
			$amm_itemData[$ctr]['Artist'] 			= array_key_exists('Artist', $amm_items[$ctr]['ItemAttributes'])	?	$amm_items[$ctr]['ItemAttributes']['Artist'] : '';
			$amm_itemData[$ctr]['Label'] 				= array_key_exists('Label', $amm_items[$ctr]['ItemAttributes'])		?	$amm_items[$ctr]['ItemAttributes']['Label'] : '';
			$amm_itemData[$ctr]['Manufacturer'] = array_key_exists('Manufacturer', $amm_items[$ctr]['ItemAttributes'])	?	$amm_items[$ctr]['ItemAttributes']['Manufacturer'] : '';
			$amm_itemData[$ctr]['Model'] 				= array_key_exists('Model', $amm_items[$ctr]['ItemAttributes'])	?	$amm_items[$ctr]['ItemAttributes']['Model'] : '';
			$amm_itemData[$ctr]['Brand'] 				= array_key_exists('Brand', $amm_items[$ctr]['ItemAttributes'])	?	$amm_items[$ctr]['ItemAttributes']['Brand'] : '';
			$amm_itemData[$ctr]['ASIN'] 				= array_key_exists('ASIN', $amm_items[$ctr]) ?	$amm_items[$ctr]['ASIN'] : '';
			$amm_itemData[$ctr]['Country'] 			= array_key_exists('amm_country', $amm_post) ?	$amm_post['amm_country'] : '';
			$amm_itemData[$ctr]['MediumImageURL']	= (array_key_exists('ImageSets', $amm_items[$ctr]))	?	$amm_items[$ctr]['ImageSets']['ImageSet']['MediumImage']['URL'] : 'http://g-images.amazon.com/images/G/01/x-site/icons/no-img-sm.gif';
			$amm_itemData[$ctr]['SmallImageURL']	= (array_key_exists('ImageSets', $amm_items[$ctr]))	?	$amm_items[$ctr]['ImageSets']['ImageSet']['SmallImage']['URL'] : 'http://g-images.amazon.com/images/G/01/x-site/icons/no-img-sm.gif';
			//$amm_itemData[$ctr]['AmazonDescription']	= (isset($amm_items[$ctr]['EditorialReviews']['EditorialReview']['Content']))	?	preg_replace("/(I[A-Z][a-z][^\/]+\\/I)","amm_stripEscape('//1')",$amm_items[$ctr]['EditorialReviews']['EditorialReview']['Content']) : '';
			$amm_itemData[$ctr]['AmazonDescription']	= (isset($amm_items[$ctr]['EditorialReviews']['EditorialReview']['Content']))	?	str_replace("\"",'&quot;',$amm_items[$ctr]['EditorialReviews']['EditorialReview']['Content']) : '';


		}

		break;
		//Edit Form for New Item
		case 'new':
		//Edit Form for Existing Item
		case 'update':
		//Edit Form for validation failure
		case 'invalid':
		foreach ($amm_post as $key=>$value) {
			$amm_post[$key] = stripslashes($value);
		}
		$amm_itemIdControl		= array_key_exists('amm_itemId', $amm_post) ? $amm_post['amm_itemId'] : '';
		$amm_authorControl 		= array_key_exists('amm_author', $amm_post) ? $amm_post['amm_author'] : '';
		$amm_directorControl	= array_key_exists('amm_director', $amm_post) ? $amm_post['amm_director'] : '';
		$amm_titleControl 		= array_key_exists('amm_title', $amm_post) ? $amm_post['amm_title'] : '';
		$amm_asinControl 			= array_key_exists('amm_asin', $amm_post) ? $amm_post['amm_asin'] : '';
		$amm_productGroupControl 	= array_key_exists('amm_productGroup', $amm_post) ? $amm_post['amm_productGroup'] : '';
		$amm_publisherControl = array_key_exists('amm_publisher', $amm_post) ? $amm_post['amm_publisher'] : '';
		$amm_artistControl 		= array_key_exists('amm_artist', $amm_post) ? $amm_post['amm_artist'] : '';
		$amm_labelControl 		= array_key_exists('amm_label', $amm_post) ? $amm_post['amm_label'] : '';
		$amm_manufacturerControl 	= array_key_exists('amm_manufacturer', $amm_post) ? $amm_post['amm_manufacturer'] : '';
		$amm_modelControl 		= array_key_exists('amm_model', $amm_post) ? $amm_post['amm_model'] : '';
		$amm_brandControl 		= array_key_exists('amm_brand', $amm_post) ? $amm_post['amm_brand'] : '';
		$amm_userCommentsControl = array_key_exists('amm_userComments', $amm_post) ? $amm_post['amm_userComments'] : '';
		$amm_ratingControl 		= array_key_exists('amm_rating', $amm_post) ? $amm_post['amm_rating'] : '';
		$amm_countryControl		=	array_key_exists('amm_country', $amm_post) ? $amm_post['amm_country'] : '';
		$amm_dateaddedControl	=	array_key_exists('amm_dateadded', $amm_post) ? $amm_post['amm_dateadded'] : '';
		$amm_smallImageURLControl	=	array_key_exists('amm_smallImageURL', $amm_post) ? $amm_post['amm_smallImageURL'] : '';
		$amm_amazonDescriptionControl	=	(empty($amm_post['amm_amazonDescription'])) ? '':$amm_post['amm_amazonDescription'];

		if (get_option('amm_amazondesc') == true){
			$amm_userCommentsControl = (''===$amm_amazonDescriptionControl)? $amm_userCommentsControl: $amm_amazonDescriptionControl ;
		}

		$amm_dateaddedLabel = $amm_dateaddedControl == '' ? '[  ]' : $amm_dateaddedControl;
		$amm_itemIdLabel = $amm_itemIdControl == '' ? '[  ]' : $amm_itemIdControl;
		break;

		//Edit Form for Main Table
		case 'main':
		// If current page number, use it
		// if not, set one!
		if((!isset($amm_get['amm_page']) || !is_numeric($amm_get['amm_page']))){
			$amm_page = 1;
		} else {
			$amm_page = $amm_get['amm_page'];
		}

		$amm_countryControl 		= '' != $amm_post['amm_country'] ? $amm_post['amm_country'] : get_option('amm_country');
		$amm_selByPrdGrpControl 	= $wpdb->get_col('SELECT DISTINCT amm_productGroup FROM '.$table_prefix.AMM_TABLE.' ORDER BY amm_productGroup;');
		$selected = array('us'=>'','uk'=>'','de'=>'','jp'=>'','fr'=>'','ca'=>'');
		$selected[$amm_countryControl] = ' selected="selected"';

		$prodValue = isset($amm_get['amm_PGrp']) ? $amm_get['amm_PGrp'] : '';
		$orderValue = isset($amm_get['amm_orderBy']) ? $amm_get['amm_orderBy'] : '';

		$prdGrp						= '' == $prodValue ? '' : " WHERE (amm_productGroup= '".$prodValue.'\')';
		switch ($orderValue) {
			case 'date_asc':
			$orderBy = 'amm_dateadded ';
			break;
			case 'rating_asc':
			$orderBy = 'amm_rating ';
			break;
			case 'rating_desc':
			$orderBy = 'amm_rating DESC ';
			break;
			case 'title_asc':
			$orderBy = 'amm_title ';
			break;
			case 'title_desc':
			$orderBy = 'amm_title DESC ';
			break;
			case 'date_desc':
			default:
			$orderBy = 'amm_dateadded DESC ';
			break;
		}
		// Figure out the total number of results in DB:
		$amm_totalResults = $wpdb->get_var("SELECT COUNT(*) AS Num FROM ".$table_prefix.AMM_TABLE.$prdGrp.';');

		// Define the number of results per page
		//$amm_maxResults = isset($amm_get['amm_maxResults']) ? $amm_get['amm_maxResults'] : 20;
		//if ($amm_maxResults >> $amm_totalResults) {$amm_maxResults = $amm_totalResults;}
		$amm_maxResults = 30; // no of items per page
		$amm_maxResults = get_option('amm_perpage');
		if ( !$amm_maxResults ) update_option('amm_perpage', 30);


		// Figure out the limit for the query based
		// on the current page number.
		$amm_from = (($amm_page * $amm_maxResults) - $amm_maxResults);
		// Figure out the total number of pages. Always round up using ceil()
		$amm_totalPages = ceil($amm_totalResults / $amm_maxResults);
		$amm_sql = 'SELECT amm_itemId, amm_title, amm_dateadded, amm_rating, amm_productGroup FROM '.$table_prefix.AMM_TABLE.$prdGrp.' ORDER BY '.$orderBy.' LIMIT '.$amm_from.', '.$amm_maxResults.';';

		if ($amm_currentItems = $wpdb->get_results($amm_sql, ARRAY_A)) {
			// Loop through the resulting array on the index $amm_currentItems[n]
			foreach ( $amm_currentItems as $amm_currentItem ) {
				// Loop through the resulting array
				foreach ( $amm_currentItem as $key => $val ) {
					// Access and format data using $key and $val pairs...
					$amm_currentItem[$key] = stripslashes($val);
				}
			}
		}
		default:
		break;
	}
	//=============================================================================

	//View Controller
	/**
	* There are three views
	* [1] The Main data table with Search Form
	* [2] Search Results
	* [3] Item Editing
	**/
	switch ($amm_view) {

		case 'item':
?>

<?php if ($amm_feedback != ''){	echo '<div id="message" class="updated fade"><p>'.$amm_feedback.'</p></div>';} ?>
<div class="wrap">
	<h2>AMM <?php _e('Management Console',AMM_DOM);?></h2>
		<h3><?php _e('Edit Media',AMM_DOM);?></h3>
		<form name="amm_item" class="amm_form" action="<?php echo AMM_URL;?>" method="post">
		<fieldset>
			<legend>Amazon Media Manager - <?php _e('Edit Item Details',AMM_DOM); ?></legend>
			<table class="amm_detail">
			<tr><td rowspan="5"><img src="<?php echo $amm_smallImageURLControl ;?>" /></td>
			<td><strong><?php _e('ASIN',AMM_DOM);?>: </strong><?php echo $amm_asinControl;?></td></tr>
			<tr><td><strong><?php _e('Country',AMM_DOM);?>: </strong><?php echo $amm_countryControl;?>
			<tr><td><strong><?php _e('ID',AMM_DOM);?>: </strong><?php echo $amm_itemIdLabel;?></td></tr>
			<tr><td><strong><?php _e('Date Added',AMM_DOM);?>: </strong><?php echo $amm_dateaddedLabel;?></td></tr>
			<tr><td><a href="<?php echo amm_detailURL($amm_countryControl,$amm_asinControl); ?>"><?php echo amm_detailURL($amm_countryControl,$amm_asinControl); ?></a></td></tr>
			</table>
			<br />
			<div class="amm_admin_left">
			<label for="amm_updateTime"><?php _e('Update Time',AMM_DOM); ?>: </label><input type="checkbox" name="amm_updateTime" checked="checked" value="yes" /><br class="amm" />
			<label for="amm_title"><?php _e('Title',AMM_DOM); ?>: </label><input type="text" name="amm_title" id="amm_title" size="70" maxlength="200" value="<?php echo $amm_titleControl;?>" /><br class="amm" />
			<label for="amm_author"><?php _e('Author',AMM_DOM); ?>: </label><input type="text" name="amm_author" id="amm_author" size="50" maxlength="128" value="<?php echo $amm_authorControl;?>" /><br class="amm" />
			<label for="amm_director"><?php _e('Director',AMM_DOM);?>: </label><input type="text" name="amm_director" id="amm_director" size="50" maxlength="128" value="<?php echo $amm_directorControl;?>" /><br class="amm" />

			<label for="amm_productGroup"><?php _e('Product Group',AMM_DOM);?>: </label>
			<select name="amm_productGroup" id="amm_productGroup">
				<?php amm_productCombo($amm_productGroupControl);?>
			</select><br class="amm" /><br class="amm" />
			<label for="amm_publisher"><?php _e('Publisher',AMM_DOM);?>: </label><input type="text" name="amm_publisher" id="amm_publisher" size="45" maxlength="128" value="<?php echo $amm_publisherControl;?>" /><br class="amm" />
			<label for="amm_artist"><?php _e('Artist',AMM_DOM);?>: </label><input type="text" name="amm_artist" id="amm_artist" size="45" maxlength="128" value="<?php echo $amm_artistControl;?>" /><br class="amm" />
			<label for="amm_label"><?php _e('Label',AMM_DOM);?>: </label><input type="text" name="amm_label" id="amm_label" size="45" maxlength="128" value="<?php echo $amm_labelControl;?>" /><br class="amm" />
			<label for="amm_manufacturer"><?php _e('Manufacturer',AMM_DOM);?>: </label><input type="text" name="amm_manufacturer" id="amm_manufacturer" size="45" maxlength="128" value="<?php echo $amm_manufacturerControl;?>" /><br class="amm" />
			<label for="amm_model"><?php _e('Model',AMM_DOM);?>: </label><input type="text" name="amm_model" id="amm_model" size="30" maxlength="128" value="<?php echo $amm_modelControl;?>" /><br class="amm" />
			<label for="amm_brand"><?php _e('Brand',AMM_DOM);?>: </label><input type="text" name="amm_brand" id="amm_brand" size="30" maxlength="128" value="<?php echo $amm_brandControl;?>" /><br class="amm" />
			</div><!--amm_admin_left-->
			<div class="amm_admin_right">
			<label for="amm_rating"><?php _e('Rate This Selection',AMM_DOM);?>: </label>
			<select name="amm_rating" id="amm_rating" tabindex="">
				<option value="0" <?php if(($amm_ratingControl == 0) || ($amm_ratingControl == '')) echo 'selected="selected"';?>><?php _e('Not Rated',AMM_DOM);?></option>
				<option value="1" <?php if($amm_ratingControl == 1) echo 'selected="selected"';?>>1 = <?php _e('Lowest',AMM_DOM);?></option>
				<option value="2" <?php if($amm_ratingControl == 2) echo 'selected="selected"';?>>2</option>
				<option value="3" <?php if($amm_ratingControl == 3) echo 'selected="selected"';?>>3</option>
				<option value="4" <?php if($amm_ratingControl == 4) echo 'selected="selected"';?>>4</option>
				<option value="5" <?php if($amm_ratingControl == 5) echo 'selected="selected"';?>>5 = <?php _e('Highest',AMM_DOM);?></option>
			</select>
			<br class="amm" />
			<label for="amm_userComments"><?php _e('User Comments',AMM_DOM);?>: </label>
			<textarea name="amm_userComments" id="amm_userComments" cols="80" rows="10"><?php echo $amm_userCommentsControl;?></textarea><br class="amm" />
			<a name="clear"></a><a href="#clear" onclick="window.document.amm_item.amm_userComments.value=''"><?php _e('Clear User Comments',AMM_DOM);?></a>
			</div><!--amm_admin_right-->
			<p class="submit"><input type="submit" class="amm_button" name="cancel" value="<?php _e('Cancel',AMM_DOM); ?>" tabindex="" />
			<input type="submit" class="amm_button" name="submit" value="<?php _e('Save &raquo;',AMM_DOM) ;?>" tabindex="" /></p>
		</fieldset>

		<input type="hidden" name="amm_itemId" id="<?php echo 'amm_itemId'.$ctr ;?>" value="<?php echo $amm_itemIdControl ;?>" />
		<input type="hidden" name="amm_asin" id="<?php echo 'amm_asin'.$ctr ;?>" value="<?php echo $amm_asinControl ;?>" />
		<input type="hidden" name="amm_country" id="<?php echo 'amm_country'.$ctr ;?>" value="<?php echo $amm_countryControl ;?>" />
		<input type="hidden" name="amm_dateadded" id="<?php echo 'amm_dateadded'.$ctr ;?>" value="<?php echo $amm_dateaddedControl ;?>" />
		<input type="hidden" name="amm_smallImageURL" id="<?php echo 'amm_smallImageURL'.$ctr ;?>" value="<?php echo $amm_smallImageURLControl ;?>" />
		<input type="hidden" name="amm_name" value="frm_editItem" />

	</form>
</div><!--end wrap-->
<?php
break;
case 'results':
?>

<?php if ($amm_feedback != ''){	echo '<div id="message" class="updated fade"><p>'.$amm_feedback.'</p></div>';} ?>
<div class="wrap">
	<h2><?php _e('Amazon Search Results', AMM_DOM);?></h2>
	<table width="100%" cellpadding="5" cellspacing="3" summary="<?php _e('This table of results shows the Image and Details for each item found at Amazon. Select the item you want by pressing the select button next to it.',AMM_DOM);?>">
		<caption><?php _e('Shown below are your search results:',AMM_DOM);?></caption>
		<tr class="alternate"><th scope="col" id="c0" width="5%"><?php _e('Result',AMM_DOM);?></th><th scope="col" id="c1"><?php _e('Image',AMM_DOM);?></th><th scope="col" id="c2"><?php _e('Information',AMM_DOM);?></th><th scope="col" id="c3" width="10%"><?php _e('Select',AMM_DOM);?></th></tr>
		<?php $alt=''; for ($ctr=0;$ctr<sizeof($amm_itemData);$ctr++): ?>
		<form class="amm_form" name="ammResult" method="post" action="<?php echo AMM_URL;?>">
		<tr <?php echo $alt;?>>
			<td headers="c0" align="center"><?php echo $ctr+1 ; ?></td>
			<td headers="c1" align="center"><a href="<?php echo $amm_itemData[$ctr]['DetailPageURL']; ?>"><img src="<?php echo $amm_itemData[$ctr]['MediumImageURL'];?>" /></a></td>
			<td headers="c2">
				<ul>
					<?php
					if(!empty($amm_itemData[$ctr]['Author'])){echo'<li>'.__('Author',AMM_DOM).': '.$amm_itemData[$ctr]['Author'].'</li>';}
					if(!empty($amm_itemData[$ctr]['Director'])){echo '<li>'.__('Director',AMM_DOM).': '.$amm_itemData[$ctr]['Director'].'</li>';}
					if(!empty($amm_itemData[$ctr]['Title'])){echo '<li>'.__('Title',AMM_DOM).': '.$amm_itemData[$ctr]['Title'].'</li>';}
					if(!empty($amm_itemData[$ctr]['ProductGroup'])){echo '<li>'.__('Product Group',AMM_DOM).': '.$amm_itemData[$ctr]['ProductGroup'].'</li>';}
					if(!empty($amm_itemData[$ctr]['Publisher'])){echo '<li>'.__('Publisher',AMM_DOM).': '.$amm_itemData[$ctr]['Publisher'].'</li>';}
					if(!empty($amm_itemData[$ctr]['Artist'])){echo '<li>'.__('Artist',AMM_DOM).': '.$amm_itemData[$ctr]['Artist'].'</li>';}
					if(!empty($amm_itemData[$ctr]['Label'])){echo '<li>'.__('Label',AMM_DOM).': '.$amm_itemData[$ctr]['Label'].'</li>';}
					if(!empty($amm_itemData[$ctr]['Manufacturer'])){echo '<li>'.__('Manufacturer',AMM_DOM).': '.$amm_itemData[$ctr]['Manufacturer'].'</li>';}
					if(!empty($amm_itemData[$ctr]['Model'])){echo '<li>'.__('Model',AMM_DOM).': '.$amm_itemData[$ctr]['Model'].'</li>';}
					if(!empty($amm_itemData[$ctr]['Brand'])){echo '<li>'.__('Brand',AMM_DOM).': '.$amm_itemData[$ctr]['Brand'].'</li>';}
					if(!empty($amm_itemData[$ctr]['ASIN'])){echo '<li>'.__('ASIN',AMM_DOM).': '.$amm_itemData[$ctr]['ASIN'].'</li>';}
					?>
				</ul>
			</td>
			<td headers="c3" align="center"><input type="submit" value="Select &raquo;" /></td>
		</tr>

		<input type="hidden" name="amm_name" value="frm_selectedItem" />
		<input type="hidden" name="amm_asin" id="<?php echo 'amm_asin'.$ctr ;?>" value="<?php echo $amm_itemData[$ctr]['ASIN'] ;?>" />
		<input type="hidden" name="amm_author" id="<?php echo 'amm_author'.$ctr ;?>" value="<?php echo $amm_itemData[$ctr]['Author'] ;?>" />
		<input type="hidden" name="amm_director" id="<?php echo 'amm_director'.$ctr ;?>" value="<?php echo $amm_itemData[$ctr]['Director'] ;?>" />
		<input type="hidden" name="amm_title" id="<?php echo 'amm_title'.$ctr ;?>" value="<?php echo $amm_itemData[$ctr]['Title'] ;?>" />
		<input type="hidden" name="amm_productGroup" id="<?php echo 'amm_productGroup'.$ctr ;?>" value="<?php echo $amm_itemData[$ctr]['ProductGroup'] ;?>" />
		<input type="hidden" name="amm_publisher" id="<?php echo 'amm_publisher'.$ctr ;?>" value="<?php echo $amm_itemData[$ctr]['Publisher'] ;?>" />
		<input type="hidden" name="amm_artist" id="<?php echo 'amm_artist'.$ctr ;?>" value="<?php echo $amm_itemData[$ctr]['Artist'] ;?>" />
		<input type="hidden" name="amm_label" id="<?php echo 'amm_label'.$ctr ;?>" value="<?php echo $amm_itemData[$ctr]['Label'] ;?>" />
		<input type="hidden" name="amm_manufacturer" id="<?php echo 'amm_manufacturer'.$ctr ;?>" value="<?php echo $amm_itemData[$ctr]['Manufacturer'] ;?>" />
		<input type="hidden" name="amm_model" id="<?php echo 'amm_model'.$ctr ;?>" value="<?php echo $amm_itemData[$ctr]['Model'] ;?>" />
		<input type="hidden" name="amm_brand" id="<?php echo 'amm_brand'.$ctr ;?>" value="<?php echo $amm_itemData[$ctr]['Brand'] ;?>" />
		<input type="hidden" name="amm_country" id="<?php echo 'amm_country'.$ctr ;?>" value="<?php echo $amm_itemData[$ctr]['Country'] ;?>" />
		<input type="hidden" name="amm_smallImageURL" id="<?php echo 'amm_smallImageURL'.$ctr ;?>" value="<?php echo $amm_itemData[$ctr]['SmallImageURL'] ;?>" />
		<input type="hidden" name="amm_amazonDescription" id="<?php echo 'amm_amazonDescription'.$ctr ;?>" value="<?php echo $amm_itemData[$ctr]['AmazonDescription'] ;?>" />

		</form>
		<?php $alt = $alt == 'class="alternate"' ? '' : 'class="alternate"'; ?>
		<?php endfor;?>
	</table>
</div><!--end wrap-->
<?php
break;
case 'main':
?>
<script language="javascript">
<!--
amm_searchIndex = new Array();
amm_searchIndex[0] = new Array("- All -","Books","Apparel","Baby","Beauty","Classical","DigitalMusic","DVD","Electronics","GourmetFood","HealthPersonalCare","Jewelry","Kitchen","Magazines","Merchants","Miscellaneous","Music","MusicalInstruments","MusicTracks","OfficeProducts","OutdoorLiving","PCHardware","PetSupplies","Photo","Restaurants","Software","SportingGoods","Tools","Toys","VHS","Video","VideoGames","Wireless","WirelessAccessories");
amm_searchIndex[1] = new Array("- All -","Books","Apparel","Baby","Beauty","Classical","DigitalMusic","DVD","Electronics","GourmetFood","HealthPersonalCare","Jewelry","Kitchen","Magazines","Merchants","Miscellaneous","Music","MusicalInstruments","MusicTracks","OfficeProducts","OutdoorLiving","PCHardware","PetSupplies","Photo","Restaurants","Software","SportingGoods","Tools","Toys","VHS","Video","VideoGames","Wireless","WirelessAccessories");
amm_searchIndex[2] = new Array("- All -","Books","Classical","DVD","Electronics","HealthPersonalCare","HomeGarden","Kitchen","Music","MusicTracks","OutdoorLiving","Software","SoftwareVideoGames","Toys","VHS","Video","VideoGames");
amm_searchIndex[3] = new Array("- All -","Books","Classical","DVD","Electronics","ForeignBooks","HealthPersonalCare","HomeGarden","Kitchen","Magazines","Music","MusicTracks","OutdoorLiving","PCHardware","Photo","Software","SoftwareVideoGames","Tools","Toys","VHS","Video","VideoGames");
amm_searchIndex[4] = new Array("- All -","Books","Classical","DVD","Electronics","ForeignBooks","Kitchen","Music","MusicTracks","Software","Toys","VHS","Video","VideoGames");
amm_searchIndex[5] = new Array("- All -","Books","Classical","DVD","ForeignBooks","Music","MusicTracks","Software","SoftwareVideoGames","VHS","VideoGames");
amm_searchIndex[6] = new Array("- All -","Books","Classical","DVD","ForeignBooks","Music","Software","SoftwareVideoGames","VHS","Video","VideoGames");

var oCountry, oCategory, oKeyword, oSubmit;

function BuildContacts2()
{

	oCountry = document.getElementById("amm_country");
	oCategory = document.getElementById("amm_searchIndex");
	oKeyword = document.getElementById("amm_keywords");
	oSubmit = document.getElementById("amm_submit");

	//if (oCountry == null || oCategory == null) {init();return;}

	oCategory.length = 0;
	num = oCountry.selectedIndex;

	//For every Item Type in the array for this country, add a new option
	for(ctr=0;ctr<amm_searchIndex[num].length;ctr++)
	{
		oCategory.options[ctr]=new Option(amm_searchIndex[num][ctr],amm_searchIndex[num][ctr]);
	}

	//Default to Books
	document.ammSearch.amm_searchIndex.selectedIndex=0;
	// oCategory.focus();  // re-insert for on-focus generation
	// enable controls
	//oCategory.disabled = oKeyword.disabled = oSubmit.disabled = false;
}
//-->
</script>

<?php if ($amm_feedback != ''){	echo '<div id="message" class="updated fade"><p>'.$amm_feedback.'</p></div>';} ?>
<div class="wrap">
	<h2><?php _e('AMM Management Console',AMM_DOM) ;?></h2>
	<form class="amm_form" name="ammSearch" method="post" action="<?php echo AMM_URL;?>">
		<fieldset>
		<legend class="options">AMM - <?php _e('Search',AMM_DOM); ?></legend>
			<label class="amm_inline" for="amm_country"><?php _e('Country',AMM_DOM);?>: </label>
			<select name="amm_country" id="amm_country" OnChange="BuildContacts2();" width="150" style="width: 150px">
				<option value="us" selected="selected"><?php _e('-- Choose a Country --',AMM_DOM);?></option>
				<option value="us" <?php echo  $selected['us']; ?>><?php _e('United States',AMM_DOM);?></option>
				<option value="uk" <?php echo  $selected['uk']; ?>><?php _e('United Kingdom',AMM_DOM);?></option>
				<option value="de" <?php echo  $selected['de']; ?>><?php _e('Germany',AMM_DOM);?></option>
				<option value="jp" <?php echo  $selected['jp']; ?>><?php _e('Japan',AMM_DOM);?></option>
				<option value="fr" <?php echo  $selected['fr']; ?>><?php _e('France',AMM_DOM);?></option>
				<option value="ca" <?php echo  $selected['ca']; ?>><?php _e('Canada',AMM_DOM);?></option>
			</select>
			<label class="amm_inline" for="amm_searchIndex"> <?php _e('Search For',AMM_DOM);?>: </label>
			<select name="amm_searchIndex" id="amm_searchIndex" OnFocus="BuildContacts2();" width="150" style="width: 150px">
				<option value="Blended"><?php _e('- All -',AMM_DOM);?></option>
			</select>
			<label class="amm_inline" for="amm_keywords"><?php _e('Keywords',AMM_DOM);?>:</label>
			<input type="text" onfocus="this.value=this.value=='- <?php _e('Enter your keywords',AMM_DOM);?> -'?'':this.value" name="amm_keywords" id="amm_keywords" size="40" maxlength="45" value="- <?php _e('Enter your keywords',AMM_DOM);?> -" tabindex="" />
			<input type="hidden" name="amm_name" value="frm_searchQuery" />
			<input type="submit" id="amm_submit" class="amm_button" name="amm_submit" value="<?php _e('Search',AMM_DOM);?> &raquo;" tabindex="" />
		</fieldset>
	</form>
	</div>
	<div class="wrap">
	<form class="amm_form" name="ammCustomiseMain" method="get" action="<?php echo AMM_URL;?>">
		<fieldset>
			<legend>AMM - <?php _e('Customise this display',AMM_DOM); ?></legend>
			<input type="hidden" name="page" value="amm.php" />
			<label class="amm_inline" for="amm_selectByProductGrp"><?php _e('Show items from this category',AMM_DOM);?>: </label>
			<select name="amm_PGrp" id="amm_PGrp" width="30">
				<option value=""><?php _e('- All -',AMM_DOM);?></option>
				<?php foreach ($amm_selByPrdGrpControl as $key=>$value) :	?>
					<option value="<?php echo $value; ?>"<?php if ($value == $prodValue) echo ' selected="selected"';?>><?php _e($value,AMM_DOM);?></option>
				<?php endforeach; ?>
			</select>
			<label class="amm_inline" for="amm_orderBy"><?php _e('Order results by',AMM_DOM);?>: </label>
			<select name="amm_orderBy" id="amm_orderBy" width="30">
				<option value="date_desc" selected="selected"><?php _e('- Order By -',AMM_DOM);?></option>
				<option value="date_asc"<?php if ($orderValue == 'date_asc') echo ' selected="selected"';?>><?php _e('Date Ascending',AMM_DOM);?></option>
				<option value="date_desc"<?php if ($orderValue == 'date_desc') echo ' selected="selected"';?>><?php _e('Date Descending',AMM_DOM);?></option>
				<option value="rating_asc"<?php if ($orderValue == 'rating_asc') echo ' selected="selected"';?>><?php _e('Rating Ascending',AMM_DOM);?></option>
				<option value="rating_desc"<?php if ($orderValue == 'rating_desc') echo ' selected="selected"';?>><?php _e('Rating Descending',AMM_DOM);?></option>
				<option value="title_asc"<?php if ($orderValue == 'title_asc') echo ' selected="selected"';?>><?php _e('Title Ascending',AMM_DOM);?></option>
				<option value="title_desc"<?php if ($orderValue == 'title_desc') echo ' selected="selected"';?>><?php _e('Title Descending',AMM_DOM);?></option>
			</select>
			<input type="submit" id="amm_orderButton" class="amm_button" name="amm_orderButton" value="<?php _e('Filter Results',AMM_DOM);?> &raquo;" tabindex="" />
	    </fieldset>
	</form>
	</div>
	<div class="wrap">
	<?php amm_drawNav($amm_get, $amm_page, $amm_totalPages); ?>
	<table width="100%" cellpadding="3" cellspacing="3">
	    <tr class="alternate">
	      <th width="8%"><?php _e('Item ID',AMM_DOM); ?></th>
	      <th ><?php _e('Title',AMM_DOM); ?></th>
	      <th ><?php _e('Group',AMM_DOM); ?></th>
	      <th width="15%"><?php _e('Date Added',AMM_DOM); ?></th>
	      <th width="5%"><?php _e('Rating',AMM_DOM); ?></th>
	      <th width="6%"><?php _e('Edit',AMM_DOM); ?></th>
	      <th width="6%"><?php _e('Delete',AMM_DOM); ?></th>
	  	</tr>
	  	<?php if (!isset($amm_currentItems)): ?>
	  	<tr><td colspan="7" align="center"><?php _e('Please add some items to your Media Manager!',AMM_DOM);?></td></tr>
	  	<?php else: ?>
	  	<?php $alt=''; foreach ($amm_currentItems as $key=>$value):?>
	  		<tr <?php echo $alt;?>>
	  			<td><?php echo $value['amm_itemId'] ?></td>
	  			<td><?php echo $value['amm_title'] ?></td>
	  			<td><?php echo $value['amm_productGroup'] ?></td>
	  			<td><?php echo $value['amm_dateadded'] ?></td>
	  			<td><?php echo $value['amm_rating'] ?></td>
	  			<td><a href="<?php echo AMM_URL.'&itemId='.$value['amm_itemId'] ;?>" title="<?php _e('Edit this item'); ?>" class="edit"><?php _e('Edit',AMM_DOM);?></a></td>
	  			<td><a href="<?php echo AMM_URL.'&itemId='.$value['amm_itemId'].'&action=del' ;?>" title="<?php _e('Delete an item from the database',AMM_DOM); ?>" class="delete" onclick="return confirm('<?php _e('You are about to delete this item!\n Press Cancel to stop or OK to delete.',AMM_DOM);?>');" ><?php _e('Delete',AMM_DOM);?></a></td>
	  		</tr>
	  	<?php $alt = $alt == 'class="alternate"' ? '' : 'class="alternate"'; ?>
	  	<?php endforeach;?>
	  	<?php endif;?>
  	</table>
	<!-- Build Page Number Hyperlinks -->
	<?php amm_drawNav($amm_get, $amm_page, $amm_totalPages); ?>
</div><!--wrap-->
<?php

default:

break;
	}
	//=============================================================================

}

function amm_drawNav($amm_get, $amm_page, $amm_totalPages){
	if ($amm_totalPages < 2) return;
?>
	<div class="amm_pageNumber"><strong><?php _e('Select a Page',AMM_DOM); ?></strong> :
		<?php

		$amm_oldForm = isset($amm_get['amm_orderBy']) ? '&amm_orderBy='.$amm_get['amm_orderBy'] : '';
		$amm_oldForm .= isset($amm_get['amm_PGrp']) ? '&amm_PGrp='.$amm_get['amm_PGrp'] : '';
		$amm_oldForm .= isset($amm_get['amm_orderButton']) ? '&amm_orderButton='.$amm_get['amm_orderButton'] : '';
		// Build Previous Link
		if($amm_page > 1){
			$prev = ($amm_page - 1);
			echo '<a href="' . AMM_URL . $amm_oldForm.'&amm_page=' . $prev . '">&laquo;&nbsp;'.__('Previous',AMM_DOM).'</a> ';
		}else{
			echo '<span style="color: #00019b;">&laquo;&nbsp;'.__('Previous',AMM_DOM).'</span> ';
		}
		for($i = 1; $i <= $amm_totalPages; $i++){
			if(($amm_page) == $i){
				echo '<span class="highlight">'.$i.'</span>' ;
			} else {
				echo ' <a href="'.AMM_URL.$amm_oldForm.'&amm_page='.$i.'">'.$i.'</a>';
			}
		}
		// Build Next Link
		if($amm_page < $amm_totalPages){
			$next = ($amm_page + 1);
			echo ' <a href="' . AMM_URL . $amm_oldForm.'&amm_page=' . $next . '">'.__('Next',AMM_DOM).'&nbsp;&raquo;</a>';
		}
		?>
	</div>
<?php
}

function amm_Options() {

	if(isset($_POST['submitted'])) {

		update_option('amm_country', $_POST['amm_country']);
		update_option('amm_associd', $_POST['amm_associd']);
		update_option('amm_devid', $_POST['amm_devid']);

		if(isset($_POST['amm_amazondesc'])){
			update_option('amm_amazondesc', true);
			$checked = ' checked="checked"';
		}else{
			update_option('amm_amazondesc', false);
			$checked='';
		}

		if (is_numeric($_POST['amm_perpage'])) update_option('amm_perpage', $_POST['amm_perpage']);

		echo '<div id="message" class="updated fade"><p>' . __('Options saved.',AMM_DOM) . '</p></div>';
	}

	$amm_country = get_option('amm_country');
	if ( !$amm_country ) update_option('amm_country', AMM_COUNTRY);
	$amm_associd = get_option('amm_associd');
	if ( !$amm_associd ) update_option('amm_associd', AMM_AFFILIATE);
	$amm_devid = get_option('amm_devid');
	if ( !$amm_devid ) update_option('amm_devid', AMM_DEVKEY);
	$amm_perpage = get_option('amm_perpage');
	if ( !$amm_perpage ) update_option('amm_perpage', 30);
	$amm_amazondesc = get_option('amm_amazondesc');
	if ( !$amm_amazondesc ) update_option('amm_amazondesc', false);


	if($amm_amazondesc == true){
		$checked = ' checked="checked"';
	}else{
		$checked='';
	}

	$selected = array('us'=>'','uk'=>'','de'=>'','jp'=>'','fr'=>'','ca'=>'');
	$selected[$amm_country] = ' selected="selected"';

?>
		<div class="wrap">
			<h2><?php _e('AMM Options', AMM_DOM); ?></h2>

			<form name="amm_options" method="post" action="<?php echo AMM_URL;?>">
			<fieldset class="options">
				<legend>
					<label><?php _e('Default Country', AMM_DOM); ?></label>
				</legend>
				<p><?php _e('Please select the country you would like AMM to use by default on things like input forms, etc.:', AMM_DOM); ?></p>
				<table width="100%" cellspacing="2" cellpadding="3" class="editform">
				<tr>
					<th width="33%" valign="top" scope="row"><?php _e('Default Country', AMM_DOM); ?>: </th>
					<td>
						<select name="amm_country">
							<option value="us" <?php echo $selected['us']; ?>><?php _e('United States', AMM_DOM); ?></option>
							<option value="uk" <?php echo $selected['uk']; ?>><?php _e('United Kingdom', AMM_DOM); ?></option>
							<option value="de" <?php echo $selected['de']; ?>><?php _e('Germany', AMM_DOM); ?></option>
							<option value="jp" <?php echo $selected['jp']; ?>><?php _e('Japan', AMM_DOM); ?></option>
							<option value="fr" <?php echo $selected['fr']; ?>><?php _e('France', AMM_DOM); ?></option>
							<option value="ca" <?php echo $selected['ca']; ?>><?php _e('Canada', AMM_DOM); ?></option>
						</select>
					</td>
				</tr>
				</table>
			</fieldset>

			<fieldset class="options">
				<legend>
					<label><?php _e('Results per page', AMM_DOM); ?></label>
				</legend>
				<p><?php _e('Please enter the number of items you wish to see per page in your AMM Control Panel.', AMM_DOM); ?></p>
				<table width="100%" cellspacing="2" cellpadding="3" class="editform">
				<tr>
					<th width="33%" valign="top" scope="row"><?php _e('Results Per Page', AMM_DOM); ?>: </th>
					<td>
						<input name="amm_perpage" type="text" id="amm_perpage" value="<?php echo $amm_perpage; ?>" size="10" /><br />
					</td>
				</tr>
				</table>
			</fieldset>

			<fieldset class="options">
				<legend>
					<label><?php _e('Use Amazon Descriptions', AMM_DOM); ?></label>
				</legend>
				<p>
				<?php _e('When adding an item to the AMM you can add your own comments. Select the following option if you wish to fill the comments box with the extended product description sent from Amazon.', AMM_DOM); ?><br />
				<?php _e('Please note: This option is experimental and does not always work as Amazon does not have descriptions for all items. Some item descriptions may contain formatting characters like /I and /B. Please check automatically generated descriptions carefully.', AMM_DOM); ?>
				</p>
				<table width="100%" cellspacing="2" cellpadding="3" class="editform">
				<tr>
					<th width="33%" valign="top" scope="row"><?php _e('Use Amazon Product Description',AMM_DOM); ?>: </th>
					<td>
					<input type="checkbox" name="amm_amazondesc"  value="true" <?php echo $checked; ?>/><br />
					</td>
				</tr>
				</table>
			</fieldset>

			<fieldset class="options">
				<legend>
					<label><?php _e('Amazon Associate ID', AMM_DOM); ?></label>
				</legend>
				<p><?php _e('The Amazon Associates program allows you to earn money by referring customers to Amazon. Please visit the <a href="http://www.amazon.com/associates">Amazon Associates website</a> for details.', AMM_DOM); ?></p>
				<p><?php _e('AMM generates links to Amazon using our own Associate ID. If you would like to use your own, you are free to do so.',AMM_DOM); ?></p>

				<table width="100%" cellspacing="2" cellpadding="3" class="editform">
				<tr>
					<th width="33%" valign="top" scope="row"><?php _e('Associate ID', AMM_DOM); ?>: </th>
					<td>
						<input name="amm_associd" type="text" id="amm_associd" value="<?php echo $amm_associd; ?>" size="50" /><br />
					</td>
				</tr>
				</table>
			</fieldset>

			<fieldset class="options">
				<legend>
					<label><?php _e('Amazon E-Commerce Service Developer ID', AMM_DOM); ?></label>
				</legend>
				<p><?php _e('AMM uses Amazon\'s web services to provide search results and information. To use the webservice, you need an account and a Developer ID. More information is available from the <a href="http://www.amazon.com/services/">Amazon Services Website</a>.', AMM_DOM); ?></p>
				<p><?php _e('Fortunately you don\'t need to have your own Developer ID to use AMM, you can simply use the one below. If you wish to use your own, enter it in the box below.', AMM_DOM); ?></p>
				<table width="100%" cellspacing="2" cellpadding="3" class="editform">
				<tr>
					<th width="33%" valign="top" scope="row"><?php _e('Amazon Developer ID:', AMM_DOM); ?> </th>
					<td>
						<input name="amm_devid" type="text" id="amm_devid" value="<?php echo $amm_devid; ?>" size="50" /><br />
					</td>
				</tr>
				</table>
			</fieldset>

			<p><?php _e('Check for new version of the AMM by visiting <a href="http://www.sozu.co.uk/">Sozu Web Studio</a>, authors of the AMM plugin for WordPress.',AMM_DOM);?></p>

			<p class="submit"><input type="submit" name="Submit" value="<?php _e('Update Options &raquo;', AMM_DOM); ?>" /></p>
			<input type="hidden" name="submitted" value="1" />
		</form>
	</div>

<?php
}

if (isset($_GET['activate']) && $_GET['activate'] == 'true') {
	add_action('init', 'amm_install');
}
add_action('admin_head', 'amm_css');
add_action('admin_menu', 'amm_addmenuitems');
add_filter('the_content', 'amm_getMediaInline', 6);
add_filter('the_content', 'amm_getMediaIDInline', 6);

?>
